.. pydartlab documentation master file, created by
   sphinx-quickstart on Tue Aug 13 19:50:40 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pyDARTlab 
==========

.. toctree::
   :maxdepth: 3
   :hidden:
   
   self
   quickstart
   exercises

.. toctree::
   :caption: Code
   :hidden:

   dartlabplot
   increments
   lorenz_96

pyDARTlab is a Python package for learning Data Assimilation based on DARTLAB
from the Data Assimilation Research Testbed (`DART <https://github.com/NCAR/DART>`_). 

.. note::

    pyDARTlab is under initial development, so please use caution.
    The MATLAB versino of `DARTLAB <https://dart.ucar.edu/tutorials/dart-lab/>`_ 
    is available through `DART <https://github.com/NCAR/DART>`_.


Contributing
============

Contributions are welcome! If you have a feature request, bug report, or a suggestion,
please open an issue on our `GitHub repository <https://github.com/NCAR/pyDARTLAB>`_.

License
=======

pyDARTLab is released under the Apache License 2.0. For more details, see the LICENSE file in the root directory of this source 
tree or visit `Apache License 2.0 <https://www.apache.org/licenses/LICENSE-2.0>`_.



